@@ -11,6 +11,7 @@ with qw(
 	App::Midgen::Role::Eval
 	App::Midgen::Role::FindMinVersion
 	App::Midgen::Role::Output
+	App::Midgen::Role::UseModule
 );
 
 # turn off experimental warnings
@@ -19,7 +20,7 @@ no if $] > 5.017010, warnings => 'experimental::smartmatch';
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.25_09';
+our $VERSION = '0.27_05';
 use English qw( -no_match_vars ); # Avoids reg-ex performance penalty
 local $OUTPUT_AUTOFLUSH = 1;
 
@@ -57,9 +58,9 @@ sub run {
 	$self->output_header();
 
 	$self->find_required_modules();
-	$self->find_required_test_modules();
+#	$self->find_required_test_modules();
 
-	p $self->{modules} if ( $self->verbose == THREE );
+	p $self->{modules} if ( $self->verbose == TWO );
 
 	$self->remove_noisy_children( $self->{package_requires} )
 		if $self->experimental;
@@ -70,6 +71,8 @@ sub run {
 	$self->remove_noisy_children( $self->{package_requires} )
 		if $self->found_twins;
 
+	$self->find_required_test_modules();
+
 	# Now we have switched to MetaCPAN-Api we can hunt for noisy children in test requires
 	if ( $self->experimental ) {
 		p $self->{test_requires} if $self->debug;
@@ -83,6 +86,21 @@ sub run {
 			}
 		}
 		p $self->{test_requires} if $self->debug;
+
+## ToDo look at resolving noisy children across types found
+#		p $self->{recommends} if $self->debug;
+#		$self->remove_noisy_children( $self->{recommends} );
+#		foreach my $module ( keys %{ $self->{recommends} } ) {
+#			if ( $self->{package_requires}{$module} ) {
+#				warn $module if $self->debug;
+#				try {
+#					delete $self->{recommends}{$module};
+#				};
+#			}
+#		}
+#		p $self->{recommends} if $self->debug;
+
+
 	}
 
 	$self->output_main_body( 'requires',      $self->{package_requires} );
@@ -93,6 +111,8 @@ sub run {
 
 	$self->output_footer();
 
+#	p $self->{modules};
+
 	return;
 }
 
@@ -267,11 +287,20 @@ sub _find_makefile_requires {
 	my $relative_dir = $File::Find::dir;
 	$relative_dir =~ s/$Working_Dir//;
 	$self->_set_looking_infile( File::Spec->catfile( $relative_dir, $filename ) );
-
 	$self->_set_ppi_document( PPI::Document->new($filename) );
+
+	# do extra test early check for use_module before hand
+#	p $filename;
+	$self->xtests_use_module();
+
+
 	my $prereqs = $self->scanner->scan_ppi_document( $self->ppi_document );
 	my @modules = $prereqs->required_modules;
 
+# todo add eval/try here
+#	$self->_xtests_eval();
+
+
 foreach my $mod_ver ( @modules ){
 	$self->{found_version}{$mod_ver} = $prereqs->requirements_for_module($mod_ver);
 }
@@ -320,7 +349,7 @@ sub _is_perlfile {
 	if ($ppi_tc) {
 
 		# check first token-comment for a she-bang
-		$a_pl_file = 1 if $ppi_tc->[0]->content =~ m/^#!.+perl.*$/;
+		$a_pl_file = 1 if $ppi_tc->[0]->content =~ m/^#!.*perl.*$/;
 	}
 
 	if ( $self->ppi_document->find('PPI::Statement::Package') || $a_pl_file ) {
@@ -356,7 +385,7 @@ sub _find_makefile_test_requires {
 	say 'looking for test_requires in: ' . $filename if $self->verbose >= TWO;
 # p $filename;
 	my $relative_dir = $File::Find::dir;
-	$relative_dir =~ s/$Working_Dir//;	
+	$relative_dir =~ s/$Working_Dir//;
 	$self->_set_looking_infile( File::Spec->catfile( $relative_dir, $filename ) );
 	# Load a Document from a file and check use and require contents
 	$self->_set_ppi_document( PPI::Document->new($filename) );
@@ -370,6 +399,10 @@ sub _find_makefile_test_requires {
 	# do extra test early to identify eval befroe hand
 	$self->_xtests_eval();
 
+	# do extra test early check for use_module before hand
+#	p $filename;
+	$self->xtests_use_module();
+
 	my $prereqs = $self->scanner->scan_ppi_document( $self->ppi_document );
 	my @modules = $prereqs->required_modules;
 
@@ -414,6 +447,10 @@ sub _process_found_modules {
 
 		#deal with ''
 		next if $module eq NONE;
+
+		# let's show every thing we can find infile
+		if ($self->format ne 'infile'){
+
 		my $distribution_name = $self->distribution_name // 'm/t';
 		given ($module) {
 			when (/perl/sxm) {
@@ -425,6 +462,7 @@ sub _process_found_modules {
 
 				# don't include our own packages here
 				next;
+#				next if $self->format ne 'infile';
 			}
 			when (/^t::/sxm) {
 
@@ -450,6 +488,7 @@ sub _process_found_modules {
 				$module = 'Padre';
 			}
 		}
+		}
 
 		# lets keep track of how many times a module include is found
 		$self->{modules}{$module}{count} += 1;
@@ -582,7 +621,7 @@ sub remove_noisy_children {
 
 				# as we only do this against -x, why not be extra vigilant
 				$valied_seperation = THREE
-					if $parent_name =~ /^Dist::Zilla|Moose|Mouse/;
+					if $parent_name =~ /^Dist::Zilla|Moose|MooseX|Moo|Mouse/;
 
 				# Checking for one degree of separation
 				# ie A::B -> A::B::C is ok but A::B::C::D is not
@@ -602,6 +641,12 @@ sub remove_noisy_children {
 						try {
 							delete $required_ref->{$child_name};
 							splice @sorted_modules, $inner_index, 1;
+
+							unless ( $self->{modules}{$parent_name} ){
+							$self->{modules}{$parent_name}{location} = 'expermental';
+							$self->{modules}{$parent_name}{version}  = $required_ref->{$parent_name};
+							$self->{modules}{$parent_name}{count} += 1;
+							}
 						};
 						p @sorted_modules if $self->debug;
 
@@ -872,7 +917,7 @@ App::Midgen - Check B<requires> & B<test_requires> of your package for CPAN incl
 
 =head1 VERSION
 
-This document describes App::Midgen version: 0.25_09
+This document describes App::Midgen version: 0.27_05
 
 =head1 SYNOPSIS
 
@@ -1013,6 +1058,12 @@ Neil Bowers E<lt>neilb@cpan.orgE<gt>
 
 Tatsuhiko Miyagawa E<lt>miyagawa@bulknews.netE<gt>
 
+Toby Inkster E<lt>tobyink@cpan.orgE<gt>
+
+Karen Etheridge E<lt>ether@cpan.orgE<gt>
+
+Oliver Gorwits E<lt>oliver@cpan.orgE<gt>
+
 =head1 COPYRIGHT
 
 Copyright E<copy> 2013 the App:Midgen L</AUTHOR> and L</CONTRIBUTORS>
@@ -1022,7 +1073,7 @@ Copyright E<copy> 2013 the App:Midgen L</AUTHOR> and L</CONTRIBUTORS>
 =head1 LICENSE
 
 This program is free software; you can redistribute it and/or modify
- it under the same terms as Perl 5 itself.
+it under the same terms as Perl 5 itself.
 
 =head1 SEE ALSO
 
