@@ -1,13 +1,14 @@
 package App::Midgen::Role::Options;
 
 use v5.10;
+
 use Types::Standard qw( Bool Int );
 use Moo::Role;
 
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.25_09';
+our $VERSION = '0.27_05';
 use Carp;
 
 #######
@@ -88,7 +89,7 @@ around [qw( debug verbose )] => sub {
 	my $self    = shift;
 	my $content = $self->$orig(@_);
 
-	if (   ( $self->quiet == 1 && $self->experimental == 1 ) 
+	if (   ( $self->quiet == 1 && $self->experimental == 1 )
 		|| ( $self->format eq 'infile' ) )
 	{
 		return 0;
@@ -114,7 +115,7 @@ App::Midgen::Role::Options - Package Options used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.25_09
+version: 0.27_05
 
 =head1 METHODS
 
@@ -166,6 +167,7 @@ See L<App::Midgen>
 
 =head1 LICENSE
 
-See L<App::Midgen>
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
