@@ -20,7 +20,7 @@ no if $] > 5.017010, warnings => 'experimental::smartmatch';
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.25_09';
+our $VERSION = '0.27_05';
 use English qw( -no_match_vars ); # Avoids reg-ex performance penalty
 local $OUTPUT_AUTOFLUSH = 1;
 
@@ -182,7 +182,7 @@ App::Midgen::Role::Output - A collection of output orientated methods used by L<
 
 =head1 VERSION
 
-version: 0.25_09
+version: 0.27_05
 
 =head1 DESCRIPTION
 
@@ -193,11 +193,11 @@ types, be that mcpan, dual-life or added distribution.
 
 =over 4
 
-=item * output_header 
+=item * output_header
 
-=item * output_main_body 
+=item * output_main_body
 
-=item * output_footer 
+=item * output_footer
 
 =item * no_index
 
@@ -227,7 +227,8 @@ See L<App::Midgen>
 
 =head1 LICENSE
 
-See L<App::Midgen>
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
