@@ -2,15 +2,15 @@ package App::Midgen::Role::Output::Infile;
 
 use v5.10;
 use Moo::Role;
-requires qw( core dual_life );
-
+requires qw( core dual_life debug );
+use Try::Tiny;
 # turn off experimental warnings
 no if $] > 5.017010, warnings => 'experimental::smartmatch';
 
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.25_09';
+our $VERSION = '0.27_05';
 use English qw( -no_match_vars );
 local $OUTPUT_AUTOFLUSH = 1;
 
@@ -43,7 +43,7 @@ sub body_infile {
 sub footer_infile {
   my $self = shift;
 
-#p $self->{modules};
+  p $self->{modules} if $self->debug;
 
   # Let's work out our padding
   my $pm_length  = 0;
@@ -53,12 +53,13 @@ sub footer_infile {
     if (length $module_name > $pm_length) {
       $pm_length = length $module_name;
     }
-
+	try {
     foreach my $foundin (sort @{$self->{modules}{$module_name}{infiles}}) {
       if (length $foundin->[0] > $dir_length) {
         $dir_length = length $foundin->[0];
       }
     }
+	};
 
   }
 
@@ -85,11 +86,12 @@ sub footer_infile {
       next if $self->{modules}{$module_name}{corelist};
     }
 
-
+	try {
     foreach my $foundin (sort @{$self->{modules}{$module_name}{infiles}}) {
       printf " | %-*s | %-*s | %-*s |\n", $pm_length, $module_name, EIGHT,
         $foundin->[1], $dir_length, $foundin->[0],;
     }
+	};
   }
 
   say "  " . "-" x EIGHT . "-" x $pm_length . "-" x $dir_length . "-" x EIGHT;
@@ -116,7 +118,7 @@ used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.25_09
+version: 0.27_05
 
 =head1 DESCRIPTION
 
@@ -156,6 +158,7 @@ See L<App::Midgen>
 
 =head1 LICENSE
 
-See L<App::Midgen>
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
